@@ -1,4 +1,9 @@
 from django.conf import settings
+
+DJANGO_PATH = settings.BASE_DIR
+if(hasattr('settings', 'PROJECT_PATH')):
+    DJANGO_PATH = settings.PROJECT_PATH
+
 from django.utils import autoreload
 from sassy_coffee import utils, compilers
 import sys, os
